# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('dnsimple')


class _ExportableConfig(types.ModuleType):
    @property
    def account(self) -> Optional[str]:
        """
        The account for API operations.
        """
        return __config__.get('account')

    @property
    def prefetch(self) -> Optional[bool]:
        """
        Flag to enable the prefetch of zone records.
        """
        return __config__.get_bool('prefetch')

    @property
    def sandbox(self) -> Optional[bool]:
        """
        Flag to enable the sandbox API.
        """
        return __config__.get_bool('sandbox')

    @property
    def token(self) -> Optional[str]:
        """
        The API v2 token for API operations.
        """
        return __config__.get('token')

    @property
    def user_agent(self) -> Optional[str]:
        """
        Custom string to append to the user agent used for sending HTTP requests to the API.
        """
        return __config__.get('userAgent')

